# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FUNCVITS_METADATA = Metadata(
    id="a906844e0fb427ee5992ebd3da45e1f05aaf100a.boutiques",
    name="mri-funcvits",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFuncvitsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_funcvits(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_funcvits(
    stem: str,
    outdir: str,
    reg: str | None = None,
    paintsurf: str | None = "white",
    sphere: str | None = "sphere",
    icosize: int | None = 10242,
    hemi: list[str] | None = ["lh", "rh"],
    svitdir: str | None = None,
    icodir: str | None = "/usr/local/freesurfer/lib/bem",
    umask: str | None = None,
    mail: str | None = None,
    noforce: bool = False,
    runner: Runner | None = None,
) -> MriFuncvitsOutputs:
    """
    Tool for functional volume to surface conversion in neuroimaging analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        stem: Template stem.
        outdir: Output directory.
        reg: Registration file.
        paintsurf: Surface upon which to paint.
        sphere: Spherical surface.
        icosize: Icosahedron size.
        hemi: Hemifield(s).
        svitdir: SVIT directory.
        icodir: ICO directory.
        umask: New umask.
        mail: User email for notifications.
        noforce: Do not create if output already exists.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFuncvitsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FUNCVITS_METADATA)
    cargs = []
    cargs.append("mri-funcvits")
    cargs.extend([
        "--stem",
        stem
    ])
    cargs.extend([
        "--outdir",
        outdir
    ])
    if reg is not None:
        cargs.extend([
            "--reg",
            reg
        ])
    if paintsurf is not None:
        cargs.extend([
            "--paintsurf",
            paintsurf
        ])
    if sphere is not None:
        cargs.extend([
            "--sphere",
            sphere
        ])
    if icosize is not None:
        cargs.extend([
            "--icosize",
            str(icosize)
        ])
    if hemi is not None:
        cargs.extend([
            "--hemi",
            *hemi
        ])
    if svitdir is not None:
        cargs.extend([
            "--svitdir",
            svitdir
        ])
    if icodir is not None:
        cargs.extend([
            "--icodir",
            icodir
        ])
    if umask is not None:
        cargs.extend([
            "--umask",
            umask
        ])
    if mail is not None:
        cargs.extend([
            "--mail",
            mail
        ])
    if noforce:
        cargs.append("--noforce")
    ret = MriFuncvitsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FUNCVITS_METADATA",
    "MriFuncvitsOutputs",
    "mri_funcvits",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSLICE_METADATA = Metadata(
    id="a89f4489f329457c259411cef949573bce403a21.boutiques",
    name="fslslice",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslsliceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslslice(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_slices: OutputPathType | None
    """Extracted 2D slices from the 3D volume"""


def fslslice(
    volume: InputPathType,
    output_basename: str | None = None,
    runner: Runner | None = None,
) -> FslsliceOutputs:
    """
    Tool to extract all slices from a 3D volume and store as 2D images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        volume: Input 3D volume (e.g. volume.nii.gz).
        output_basename: Output basename for extracted slices.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslsliceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSLICE_METADATA)
    cargs = []
    cargs.append("fslslice")
    cargs.append(execution.input_file(volume))
    if output_basename is not None:
        cargs.append(output_basename)
    ret = FslsliceOutputs(
        root=execution.output_file("."),
        output_slices=execution.output_file(output_basename + "_slice*.nii.gz") if (output_basename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSLICE_METADATA",
    "FslsliceOutputs",
    "fslslice",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEXTURE_COOCCURRENCE_FEATURES_METADATA = Metadata(
    id="91591f77263330ed7a5bfa1c36e1edb089c3c166.boutiques",
    name="TextureCooccurrenceFeatures",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class TextureCooccurrenceFeaturesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `texture_cooccurrence_features(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    features_output: OutputPathType
    """The output file containing the calculated texture co-occurrence
    features."""


def texture_cooccurrence_features(
    image_dimension: int,
    input_image: InputPathType,
    number_of_bins_per_axis: int | None = 256,
    mask_image: InputPathType | None = None,
    mask_label: int | None = 1,
    runner: Runner | None = None,
) -> TextureCooccurrenceFeaturesOutputs:
    """
    Calculates texture co-occurrence features such as Energy, Entropy, Inverse
    Difference Moment, Inertia, Cluster Shade, and Cluster Prominence from an input
    image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the input image, e.g., 2 for 2D\
            images, 3 for 3D images.
        input_image: The input image file for which texture co-occurrence\
            features will be calculated.
        number_of_bins_per_axis: The number of bins per axis to be used in the\
            histogram for texture calculation. Defaults to 256.
        mask_image: Optional mask image to specify the regions of interest in\
            the input image for which features will be calculated.
        mask_label: Label value in the mask image to specify which region to\
            process. Defaults to 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TextureCooccurrenceFeaturesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEXTURE_COOCCURRENCE_FEATURES_METADATA)
    cargs = []
    cargs.append("TextureCooccurrenceFeatures")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    if number_of_bins_per_axis is not None:
        cargs.append(str(number_of_bins_per_axis))
    if mask_image is not None:
        cargs.append(execution.input_file(mask_image))
    if mask_label is not None:
        cargs.append(str(mask_label))
    ret = TextureCooccurrenceFeaturesOutputs(
        root=execution.output_file("."),
        features_output=execution.output_file(pathlib.Path(input_image).name + "_features.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEXTURE_COOCCURRENCE_FEATURES_METADATA",
    "TextureCooccurrenceFeaturesOutputs",
    "texture_cooccurrence_features",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_THICKNESS_COMPARISON_METADATA = Metadata(
    id="7af273460a46de42cbe519e79fb65ca38e3c1fff.boutiques",
    name="mris_thickness_comparison",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisThicknessComparisonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_thickness_comparison(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_thickness_comparison(
    subject: str,
    hemi: str,
    thickness_file: InputPathType,
    w_file: InputPathType,
    labels: list[str],
    runner: Runner | None = None,
) -> MrisThicknessComparisonOutputs:
    """
    Tool to compare cortical thickness measurements between two or more specified
    labels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        hemi: Hemisphere (e.g., lh or rh).
        thickness_file: File containing thickness measurements.
        w_file: W file for cortical thickness comparison.
        labels: List of labels to compare, separated by spaces.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisThicknessComparisonOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_THICKNESS_COMPARISON_METADATA)
    cargs = []
    cargs.append("mris_thickness_comparison")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(execution.input_file(thickness_file))
    cargs.append(execution.input_file(w_file))
    cargs.extend(labels)
    ret = MrisThicknessComparisonOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_THICKNESS_COMPARISON_METADATA",
    "MrisThicknessComparisonOutputs",
    "mris_thickness_comparison",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_TORT_PLOT_DP_ALIGN_METADATA = Metadata(
    id="85f0f975299d8bde02839f551146666cba69ff1f.boutiques",
    name="adjunct_tort_plot_dp_align",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctTortPlotDpAlignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_tort_plot_dp_align(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    align_params: OutputPathType
    """Text file containing 6 columns of data for the rigid-body alignment
    parameters estimated by DIFFPREP."""
    enorm_file: OutputPathType
    """Text file with 1 column of data, the Euclidean norm of the differences of
    the rigid body alignment parameters."""
    plot_jpg: OutputPathType
    """A plot of enorm and the alignment parameters in JPG format."""
    plot_svg: OutputPathType
    """A plot of enorm and the alignment parameters in SVG format."""


def adjunct_tort_plot_dp_align(
    input_file: InputPathType,
    output_prefix: str,
    enorm_max: float | None = None,
    enorm_hline: float | None = None,
    no_svg: bool = False,
    runner: Runner | None = None,
) -> AdjunctTortPlotDpAlignOutputs:
    """
    Tool to display the rigid-body alignment parameters from TORTOISE's DIFFPREP,
    useful for analyzing subject motion in DWI data.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Name of DIFFPREP-produced file to parse, probably ending in\
            '_transformations.txt'.
        output_prefix: Base of output files; can contain path information.\
            Should *not* include any extension.
        enorm_max: Specify max value of y-axis of enorm plot in SVG image.\
            Useful for having a constant value across a study.
        enorm_hline: Specify value of a horizontal, dotted, bright cyan line\
            for the enorm plot in SVG image. Can help with visualization.
        no_svg: Opt to turn off even checking to plot an SVG version of the\
            figure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctTortPlotDpAlignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_TORT_PLOT_DP_ALIGN_METADATA)
    cargs = []
    cargs.append("adjunct_tort_plot_dp_align")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-prefix",
        output_prefix
    ])
    if enorm_max is not None:
        cargs.extend([
            "-enorm_max",
            str(enorm_max)
        ])
    if enorm_hline is not None:
        cargs.extend([
            "-enorm_hline",
            str(enorm_hline)
        ])
    if no_svg:
        cargs.append("-no_svg")
    ret = AdjunctTortPlotDpAlignOutputs(
        root=execution.output_file("."),
        align_params=execution.output_file(output_prefix + "_align.1D"),
        enorm_file=execution.output_file(output_prefix + "_enorm.1D"),
        plot_jpg=execution.output_file(output_prefix + ".jpg"),
        plot_svg=execution.output_file(output_prefix + ".svg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_TORT_PLOT_DP_ALIGN_METADATA",
    "AdjunctTortPlotDpAlignOutputs",
    "adjunct_tort_plot_dp_align",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DIST_SURF_LABEL_METADATA = Metadata(
    id="72b4cdbb35a27d1559099cff0310255f2417fec4.boutiques",
    name="mri_dist_surf_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDistSurfLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_dist_surf_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """Output file containing computed distances."""


def mri_dist_surf_label(
    surface: InputPathType,
    label_file: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> MriDistSurfLabelOutputs:
    """
    Computes distances from input surface to label points or waypoints.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Input surface file.
        label_file: Input label file.
        output: Output file for distances.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDistSurfLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DIST_SURF_LABEL_METADATA)
    cargs = []
    cargs.append("mri_dist_surf_label")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(label_file))
    cargs.append(output)
    ret = MriDistSurfLabelOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DIST_SURF_LABEL_METADATA",
    "MriDistSurfLabelOutputs",
    "mri_dist_surf_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_ALL_LABELS_METADATA = Metadata(
    id="7e86c136e5dca86f55d15560397ec44a7f6e3348.boutiques",
    name="map_all_labels",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MapAllLabelsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_all_labels(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The output of the mapping process"""


def map_all_labels(
    which: str,
    fname: str,
    hemi: str,
    spherical_surf: str,
    subjects: list[str],
    output: str,
    runner: Runner | None = None,
) -> MapAllLabelsOutputs:
    """
    Tool for mapping labels onto subject surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        which: Select what to map (e.g. coords, label, vals, curv, area).
        fname: Filename related to the mapping.
        hemi: Hemisphere to process (e.g. lh, rh).
        spherical_surf: Spherical surface to use.
        subjects: List of subject identifiers.
        output: Output path.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapAllLabelsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_ALL_LABELS_METADATA)
    cargs = []
    cargs.append("map_all_labels")
    cargs.append(which)
    cargs.append(fname)
    cargs.append(hemi)
    cargs.append(spherical_surf)
    cargs.extend(subjects)
    cargs.append(output)
    ret = MapAllLabelsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_ALL_LABELS_METADATA",
    "MapAllLabelsOutputs",
    "map_all_labels",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLVBM_1_BET_METADATA = Metadata(
    id="b14f656e797f3613fc30f4f42a5942f8c36bc438.boutiques",
    name="fslvbm_1_bet",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Fslvbm1BetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslvbm_1_bet(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslvbm_1_bet(
    increased_robustness: bool = False,
    bet_parameters: str | None = None,
    runner: Runner | None = None,
) -> Fslvbm1BetOutputs:
    """
    Brain extraction for VBM using FSL BET.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        increased_robustness: Increased robustness in the brain extraction when\
            a lot of neck is present.
        bet_parameters: Additional options to be passed on to BET.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fslvbm1BetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLVBM_1_BET_METADATA)
    cargs = []
    cargs.append("fslvbm_1_bet")
    if increased_robustness:
        cargs.append("-N")
    if bet_parameters is not None:
        cargs.append(bet_parameters)
    ret = Fslvbm1BetOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLVBM_1_BET_METADATA",
    "Fslvbm1BetOutputs",
    "fslvbm_1_bet",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FILL_METADATA = Metadata(
    id="45567bfdadd532485f2ed2b4fee5ffc3e7f9d609.boutiques",
    name="mri_fill",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFillOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fill(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filled_volume: OutputPathType
    """The filled volume for the cortical reconstruction, used for subsequent
    surface tessellation"""


def mri_fill(
    input_mr_dir: str,
    output_mr_dir: str,
    threshold: float | None = None,
    xform_name: str | None = None,
    segmentation_file: InputPathType | None = None,
    atlas_file: InputPathType | None = None,
    fill_ven: bool = False,
    seed_cc_tal: list[float] | None = None,
    seed_pons_tal: list[float] | None = None,
    seed_lh_tal: list[float] | None = None,
    seed_rh_tal: list[float] | None = None,
    seed_cc_vox: list[float] | None = None,
    seed_pons_vox: list[float] | None = None,
    auto_man_files: list[str] | None = None,
    no_auto_man: bool = False,
    pointset_args: list[str] | None = None,
    ctab_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriFillOutputs:
    """
    Tool for creating hemispheric cutting planes and filling white matter for
    surface tessellation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_mr_dir: Input MR directory.
        output_mr_dir: Output MR directory.
        threshold: Specify fill_holes threshold (default=1).
        xform_name: Use xform dst offset to get an accurate Talairach volume.
        segmentation_file: ASEG volume used to perform fill.
        atlas_file: Specify atlas to use for auto-filling.
        fill_ven: Fill ventricles.
        seed_cc_tal: Talairach coords of the seed for the corpus callosum\
            (three numerical values required).
        seed_pons_tal: Talairach coords of the seed for the pons (three\
            numerical values required).
        seed_lh_tal: Talairach coords of the white matter seed for the left\
            hemisphere (three numerical values required).
        seed_rh_tal: Talairach coords of the white matter seed for the right\
            hemisphere (three numerical values required).
        seed_cc_vox: Voxel coords of the seed for the corpus callosum (three\
            numerical values required).
        seed_pons_vox: Voxel coords of the seed for the pons (three numerical\
            values required).
        auto_man_files: Get edits based on the difference between auto and man\
            and apply to the output.
        no_auto_man: Turns off the -auto-man option.
        pointset_args: Stand-alone option: takes one or more pointsets and\
            fills in all the voxels that intersect lines connecting any two points\
            within a given point set.
        ctab_file: Embed color table in the output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFillOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FILL_METADATA)
    cargs = []
    cargs.append("mri_fill")
    cargs.append(input_mr_dir)
    cargs.append(output_mr_dir)
    if threshold is not None:
        cargs.extend([
            "-T",
            str(threshold)
        ])
    if xform_name is not None:
        cargs.extend([
            "-xform",
            xform_name
        ])
    if segmentation_file is not None:
        cargs.extend([
            "-segmentation",
            execution.input_file(segmentation_file)
        ])
    if atlas_file is not None:
        cargs.extend([
            "-atlas",
            execution.input_file(atlas_file)
        ])
    if fill_ven:
        cargs.append("-fillven")
    if seed_cc_tal is not None:
        cargs.extend([
            "-C",
            *map(str, seed_cc_tal)
        ])
    if seed_pons_tal is not None:
        cargs.extend([
            "-P",
            *map(str, seed_pons_tal)
        ])
    if seed_lh_tal is not None:
        cargs.extend([
            "-lh",
            *map(str, seed_lh_tal)
        ])
    if seed_rh_tal is not None:
        cargs.extend([
            "-rh",
            *map(str, seed_rh_tal)
        ])
    if seed_cc_vox is not None:
        cargs.extend([
            "-CV",
            *map(str, seed_cc_vox)
        ])
    if seed_pons_vox is not None:
        cargs.extend([
            "-PV",
            *map(str, seed_pons_vox)
        ])
    if auto_man_files is not None:
        cargs.extend([
            "-auto-man",
            *auto_man_files
        ])
    if no_auto_man:
        cargs.append("-no-auto-man")
    if pointset_args is not None:
        cargs.extend([
            "-pointset",
            *pointset_args
        ])
    if ctab_file is not None:
        cargs.extend([
            "-ctab",
            execution.input_file(ctab_file)
        ])
    ret = MriFillOutputs(
        root=execution.output_file("."),
        filled_volume=execution.output_file(output_mr_dir + "/filled"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FILL_METADATA",
    "MriFillOutputs",
    "mri_fill",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_AA_SHRINKWRAP_METADATA = Metadata(
    id="35496254b602549d226c6de261156b86767e1155.boutiques",
    name="mris_AA_shrinkwrap",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisAaShrinkwrapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_aa_shrinkwrap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_aa_shrinkwrap(
    t1_vol: InputPathType,
    pd_vol: InputPathType,
    output_dir: str,
    omit_self_intersection: bool = False,
    create_curvature_area: bool = False,
    average_curvature: float | None = 10,
    white_only: bool = False,
    runner: Runner | None = None,
) -> MrisAaShrinkwrapOutputs:
    """
    This program positions the tessellation of the cortical surface at the white
    matter surface, then the gray matter surface and generates surface files for
    these surfaces as well as a 'curvature' file for the cortical thickness, and a
    surface file which approximates layer IV of the cortical sheet.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_vol: T1 volume file.
        pd_vol: PD volume file.
        output_dir: Output directory.
        omit_self_intersection: Omit self-intersection and only generate\
            gray/white surface.
        create_curvature_area: Create curvature and area files from white\
            matter surface.
        average_curvature: Average curvature values a specified number of times\
            (default=10).
        white_only: Only generate white matter surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisAaShrinkwrapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_AA_SHRINKWRAP_METADATA)
    cargs = []
    cargs.append("mris_AA_shrinkwrap")
    cargs.append(execution.input_file(t1_vol))
    cargs.append(execution.input_file(pd_vol))
    cargs.append(output_dir)
    if omit_self_intersection:
        cargs.append("-q")
    if create_curvature_area:
        cargs.append("-c")
    if average_curvature is not None:
        cargs.extend([
            "-a",
            str(average_curvature)
        ])
    if white_only:
        cargs.append("-whiteonly")
    ret = MrisAaShrinkwrapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_AA_SHRINKWRAP_METADATA",
    "MrisAaShrinkwrapOutputs",
    "mris_aa_shrinkwrap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CRUISETO_AFNI_METADATA = Metadata(
    id="4b72eb1971f7fa8dc1755dacfa39929795432071.boutiques",
    name="3dCRUISEtoAFNI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dCruisetoAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_cruiseto_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_cruiseto_afni(
    input_: InputPathType,
    novolreg: bool = False,
    noxform: bool = False,
    setenv: str | None = None,
    trace_: bool = False,
    trace_2: bool = False,
    nomall: bool = False,
    yesmall: bool = False,
    help_: bool = False,
    h: bool = False,
    runner: Runner | None = None,
) -> V3dCruisetoAfniOutputs:
    """
    Converts a CRUISE dataset defined by a header in OpenDX format.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input CRUISE header file in OpenDX format.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        noxform: Same as -novolreg.
        setenv: Set environment variable ENVname to be ENVvalue. Quotes are\
            necessary. Example: suma -setenv "'SUMA_BackgroundColor = 1 0 1'".
        trace_: Turns on extreme tracing.
        trace_2: Turns on extreme tracing.
        nomall: Turn off memory tracing.
        yesmall: Turn on memory tracing (default).
        help_: The entire help output.
        h: Displays mini help; in many cases, it's the same as -help.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dCruisetoAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CRUISETO_AFNI_METADATA)
    cargs = []
    cargs.append("3dCRUISEtoAFNI")
    cargs.extend([
        "-input",
        execution.input_file(input_)
    ])
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if setenv is not None:
        cargs.extend([
            "-setenv",
            setenv
        ])
    if trace_:
        cargs.append("-TRACE")
    if trace_2:
        cargs.append("-TRACE")
    if nomall:
        cargs.append("-nomall")
    if yesmall:
        cargs.append("-yesmall")
    if help_:
        cargs.append("-help")
    if h:
        cargs.append("-h")
    ret = V3dCruisetoAfniOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dCruisetoAfniOutputs",
    "V_3D_CRUISETO_AFNI_METADATA",
    "v_3d_cruiseto_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_INTRODUCTION_SH_METADATA = Metadata(
    id="ea6433a22b9e7d78a34c893edf721a839a07cf99.boutiques",
    name="antsIntroduction.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsIntroductionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_introduction_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ants_introduction_sh(
    image_dimension: typing.Literal[2, 3],
    reference_image: InputPathType,
    input_image: InputPathType,
    force: typing.Literal[0, 1] | None = 1,
    labels_in_fixed_image_space: str | None = None,
    max_iterations: int | None = None,
    n4_bias_field_correction: typing.Literal[0, 1] | None = 0,
    outprefix: str | None = None,
    quality_check: typing.Literal[0, 1] | None = 0,
    similarity_metric: str | None = None,
    transformation_model: str | None = None,
    runner: Runner | None = None,
) -> AntsIntroductionShOutputs:
    """
    Script for registration using ANTS with compulsory and optional arguments.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Image dimension for registration: 2 or 3.
        reference_image: Reference image for registration.
        input_image: Input image to be registered.
        force: Force script to proceed even if headers may be incompatible.
        labels_in_fixed_image_space: Labels in fixed image space to deform to\
            moving image.
        max_iterations: Maximum number of iterations.
        n4_bias_field_correction: N4 Bias Field Correction of moving image: 0\
            for off, 1 for on.
        outprefix: A prefix that is prepended to all output files.
        quality_check: Perform a Quality Check (QC) of the result: 0 for off, 1\
            for on.
        similarity_metric: Type of similarity metric used for registration.
        transformation_model: Type of transformation model used for\
            registration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsIntroductionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_INTRODUCTION_SH_METADATA)
    cargs = []
    cargs.append("antsIntroduction.sh")
    cargs.extend([
        "-d",
        str(image_dimension)
    ])
    cargs.extend([
        "-r",
        execution.input_file(reference_image)
    ])
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if force is not None:
        cargs.extend([
            "-f",
            str(force)
        ])
    if labels_in_fixed_image_space is not None:
        cargs.extend([
            "-l",
            labels_in_fixed_image_space
        ])
    if max_iterations is not None:
        cargs.extend([
            "-m",
            str(max_iterations)
        ])
    if n4_bias_field_correction is not None:
        cargs.extend([
            "-n",
            str(n4_bias_field_correction)
        ])
    if outprefix is not None:
        cargs.extend([
            "-o",
            outprefix
        ])
    if quality_check is not None:
        cargs.extend([
            "-q",
            str(quality_check)
        ])
    if similarity_metric is not None:
        cargs.extend([
            "-s",
            similarity_metric
        ])
    if transformation_model is not None:
        cargs.extend([
            "-t",
            transformation_model
        ])
    ret = AntsIntroductionShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_INTRODUCTION_SH_METADATA",
    "AntsIntroductionShOutputs",
    "ants_introduction_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXVIVO_HEMI_PROC_METADATA = Metadata(
    id="9ef40c3f2cab9928f235df79043cbc38b92918d6.boutiques",
    name="exvivo-hemi-proc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ExvivoHemiProcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `exvivo_hemi_proc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def exvivo_hemi_proc(
    flashdir: str,
    outdir: str,
    subject: str,
    right_hemi: bool = False,
    suptent: bool = False,
    no_rotate: bool = False,
    t1thresh: float | None = None,
    threads: float | None = None,
    check_only: bool = False,
    prep_only: bool = False,
    mask_only: bool = False,
    samseg_only: bool = False,
    stop_mmppsp_after: str | None = None,
    force: bool = False,
    runner: Runner | None = None,
) -> ExvivoHemiProcOutputs:
    """
    Processes whole hemisphere data for Jeans entorhinal subfield labeling project.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        flashdir: Path to the FLASH data directory.
        outdir: Output directory where results will be saved.
        subject: Full path to the subject.
        right_hemi: Process right hemisphere.
        suptent: Indicate no tentorium (cblum and bstem) in the sample.
        no_rotate: Indicate rotation is not needed.
        t1thresh: T1 threshold, default is 415.
        threads: Number of threads to use.
        check_only: Only perform check, without further processing.
        prep_only: Only run up to manual rotation.
        mask_only: Only run up to creation of masks.
        samseg_only: Only run up to samseg.
        stop_mmppsp_after: Stop processing after a specific step\
            {tess,fix,preaparc,sphere,spherereg,white,pial}.
        force: Force the execution, overriding checks.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExvivoHemiProcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXVIVO_HEMI_PROC_METADATA)
    cargs = []
    cargs.append("exvivo-hemi-proc")
    cargs.extend([
        "--i",
        flashdir
    ])
    cargs.extend([
        "--o",
        outdir
    ])
    cargs.extend([
        "--s",
        subject
    ])
    if right_hemi:
        cargs.append("--rh")
    if suptent:
        cargs.append("--suptent")
    if no_rotate:
        cargs.append("--no-rotate")
    if t1thresh is not None:
        cargs.extend([
            "--t1thresh",
            str(t1thresh)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if check_only:
        cargs.append("--check-only")
    if prep_only:
        cargs.append("--prep-only")
    if mask_only:
        cargs.append("--mask-only")
    if samseg_only:
        cargs.append("--samseg-only")
    if stop_mmppsp_after is not None:
        cargs.extend([
            "--stop-mmppsp-after",
            stop_mmppsp_after
        ])
    if force:
        cargs.append("--force")
    ret = ExvivoHemiProcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXVIVO_HEMI_PROC_METADATA",
    "ExvivoHemiProcOutputs",
    "exvivo_hemi_proc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SCLIMBIC_SEG_METADATA = Metadata(
    id="1ec74b6aef5bd2cf5b900639f4d636aba2915275.boutiques",
    name="mri_sclimbic_seg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSclimbicSegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_sclimbic_seg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """Segmentation output file."""


def mri_sclimbic_seg(
    input_file: str,
    output_file: str,
    subjects: list[str] | None = None,
    subjects_dir: str | None = None,
    conform: bool = False,
    etiv: bool = False,
    exclude_labels: list[str] | None = None,
    keep_ac: bool = False,
    vox_count_volumes: bool = False,
    model_file: InputPathType | None = None,
    ctab_file: InputPathType | None = None,
    population_stats: InputPathType | None = None,
    debug: bool = False,
    vmp: bool = False,
    threads: int | None = None,
    tal_xfm: str | None = None,
    write_posteriors: bool = False,
    write_volumes: bool = False,
    write_qa_stats: bool = False,
    preprocess_7_t: bool = False,
    percentile: float | None = None,
    cuda_device: str | None = None,
    output_base: str | None = None,
    no_cite: bool = False,
    nchannels: int | None = None,
    runner: Runner | None = None,
) -> MriSclimbicSegOutputs:
    """
    Segment subcortical limbic structures using Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: T1-w image(s) to segment. Can be a path to a single image\
            or a directory of images.
        output_file: Segmentation output (required if --i is provided). Must be\
            the same type as the input path (a single file or directory).
        subjects: Process a series of freesurfer recon-all subjects (enables\
            subject-mode).
        subjects_dir: Set the subjects directory (overrides the SUBJECTS_DIR\
            env variable).
        conform: Resample input to 1mm-iso; results will be put back in native\
            resolution.
        etiv: Include eTIV in volume stats (enabled by default in subject-mode\
            and --tal).
        exclude_labels: List of label IDs to exclude in any output stats files.
        keep_ac: Explicitly keep anterior commissure in the volume/qa files.
        vox_count_volumes: Use discrete voxel count for label volumes.
        model_file: Alternative model weights to load.
        ctab_file: Alternative color lookup table to embed in segmentation.\
            Must be minimal, including 0, and sorted.
        population_stats: Alternative population volume stats for QA output.
        debug: Enable debug logging.
        vmp: Enable printing of vmpeak at the end.
        threads: Number of threads to use. Default is 1.
        tal_xfm: Alternative talairach xfm transform for estimating TIV. Can be\
            file or suffix (for multiple inputs).
        write_posteriors: Save the label posteriors.
        write_volumes: Save label volume stats (enabled by default in\
            subject-mode).
        write_qa_stats: Save QA stats (z and confidence).
        preprocess_7_t: Preprocess 7T images (just sets percentile to 99.9).
        percentile: Use intensity percentile threshold for normalization.
        cuda_device: Cuda device for GPU support.
        output_base: String to use in output file name; default is sclimbic.
        no_cite: Do not cite sclimbic paper at the end.
        nchannels: Number of channels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSclimbicSegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SCLIMBIC_SEG_METADATA)
    cargs = []
    cargs.append("mri_sclimbic_seg")
    cargs.extend([
        "-i",
        input_file
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    if subjects is not None:
        cargs.extend([
            "-s",
            *subjects
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if conform:
        cargs.append("--conform")
    if etiv:
        cargs.append("--etiv")
    if exclude_labels is not None:
        cargs.extend([
            "--exclude",
            *exclude_labels
        ])
    if keep_ac:
        cargs.append("--keep_ac")
    if vox_count_volumes:
        cargs.append("--vox-count-volumes")
    if model_file is not None:
        cargs.extend([
            "--model",
            execution.input_file(model_file)
        ])
    if ctab_file is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab_file)
        ])
    if population_stats is not None:
        cargs.extend([
            "--population-stats",
            execution.input_file(population_stats)
        ])
    if debug:
        cargs.append("--debug")
    if vmp:
        cargs.append("--vmp")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if tal_xfm is not None:
        cargs.extend([
            "--tal",
            tal_xfm
        ])
    if write_posteriors:
        cargs.append("--write_posteriors")
    if write_volumes:
        cargs.append("--write_volumes")
    if write_qa_stats:
        cargs.append("--write_qa_stats")
    if preprocess_7_t:
        cargs.append("--7T")
    if percentile is not None:
        cargs.extend([
            "--percentile",
            str(percentile)
        ])
    if cuda_device is not None:
        cargs.extend([
            "--cuda-device",
            cuda_device
        ])
    if output_base is not None:
        cargs.extend([
            "--output-base",
            output_base
        ])
    if no_cite:
        cargs.append("--no-cite-sclimbic")
    if nchannels is not None:
        cargs.extend([
            "--nchannels",
            str(nchannels)
        ])
    ret = MriSclimbicSegOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SCLIMBIC_SEG_METADATA",
    "MriSclimbicSegOutputs",
    "mri_sclimbic_seg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MASKDYADS_METADATA = Metadata(
    id="7202ebf9fac4f093011a592184e5ec67cfb619d5.boutiques",
    name="maskdyads",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MaskdyadsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `maskdyads(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def maskdyads(
    dyads: InputPathType,
    fsamples: InputPathType,
    threshold: float | None = 0.05,
    runner: Runner | None = None,
) -> MaskdyadsOutputs:
    """
    Tool to mask dyads with threshold.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        dyads: Input dyads file.
        fsamples: Input fsamples file.
        threshold: Threshold (default is 0.05).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MaskdyadsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MASKDYADS_METADATA)
    cargs = []
    cargs.append("maskdyads")
    cargs.append(execution.input_file(dyads))
    cargs.append(execution.input_file(fsamples))
    if threshold is not None:
        cargs.extend([
            "[THR]",
            str(threshold)
        ])
    ret = MaskdyadsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MASKDYADS_METADATA",
    "MaskdyadsOutputs",
    "maskdyads",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCMDIR_INFO_MGH_METADATA = Metadata(
    id="7ccff8790fdd0d584c57e3c31a9bf9ffd1e90e36.boutiques",
    name="dcmdir-info-mgh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DcmdirInfoMghOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcmdir_info_mgh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    converted_mgz_files: OutputPathType
    """Converted DICOM files to MGZ format with naming sequencename_runR.mgz,
    where R is the run number"""


def dcmdir_info_mgh(
    dicomdir: str,
    unpackdir: str | None = None,
    version: bool = False,
    help_: bool = False,
    nopre: bool = False,
    runner: Runner | None = None,
) -> DcmdirInfoMghOutputs:
    """
    Scans a DICOM directory and extracts information about each series.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        dicomdir: Input DICOM directory.
        unpackdir: Directory where the unpacked data will be stored (optional).\
            If specified, DICOM files are converted to MGZ format.
        version: Print version and exit.
        help_: Print help and exit.
        nopre: Do not assume filenames use the NNNNNN- prefix convention.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DcmdirInfoMghOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCMDIR_INFO_MGH_METADATA)
    cargs = []
    cargs.extend([
        "-mgh",
        "dcmdir-info" + dicomdir
    ])
    if unpackdir is not None:
        cargs.append(unpackdir)
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    if nopre:
        cargs.append("--nopre")
    ret = DcmdirInfoMghOutputs(
        root=execution.output_file("."),
        converted_mgz_files=execution.output_file("sequencename_run*.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCMDIR_INFO_MGH_METADATA",
    "DcmdirInfoMghOutputs",
    "dcmdir_info_mgh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_ESTIMATE_FWHM_METADATA = Metadata(
    id="5a208f16e948f98d42112e2bc0a3ea2e8dd7f5ff.boutiques",
    name="cifti-estimate-fwhm",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiEstimateFwhmWholeFile:
    """
    estimate for the whole file at once, not each column separately.
    """
    opt_demean: bool = False
    """subtract the mean image before estimating smoothness"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-whole-file")
        if self.opt_demean:
            cargs.append("-demean")
        return cargs


@dataclasses.dataclass
class CiftiEstimateFwhmSurface:
    """
    specify an input surface.
    """
    structure: str
    """what structure to use this surface for"""
    surface: InputPathType
    """the surface file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.surface))
        return cargs


class CiftiEstimateFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_estimate_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_estimate_fwhm(
    cifti: InputPathType,
    opt_merged_volume: bool = False,
    opt_column_column: int | None = None,
    whole_file: CiftiEstimateFwhmWholeFile | None = None,
    surface: list[CiftiEstimateFwhmSurface] | None = None,
    runner: Runner | None = None,
) -> CiftiEstimateFwhmOutputs:
    """
    Estimate fwhm smoothness of a cifti file.
    
    Estimate the smoothness of the components of the cifti file, printing the
    estimates to standard output. If -merged-volume is used, all voxels are used
    as a single component, rather than separated by structure.
    
    <structure> must be one of the following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the input cifti file.
        opt_merged_volume: treat volume components as if they were a single\
            component.
        opt_column_column: only output estimates for one column: the column\
            number.
        whole_file: estimate for the whole file at once, not each column\
            separately.
        surface: specify an input surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiEstimateFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ESTIMATE_FWHM_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-estimate-fwhm")
    cargs.append(execution.input_file(cifti))
    if opt_merged_volume:
        cargs.append("-merged-volume")
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            str(opt_column_column)
        ])
    if whole_file is not None:
        cargs.extend(whole_file.run(execution))
    if surface is not None:
        cargs.extend([a for c in [s.run(execution) for s in surface] for a in c])
    ret = CiftiEstimateFwhmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_ESTIMATE_FWHM_METADATA",
    "CiftiEstimateFwhmOutputs",
    "CiftiEstimateFwhmSurface",
    "CiftiEstimateFwhmWholeFile",
    "cifti_estimate_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DECONVOLVE_METADATA = Metadata(
    id="3c5bd8bab8c9c3f4b4586c2e6fc553ef1b03f1e4.boutiques",
    name="3dDeconvolve",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDeconvolveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_deconvolve(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    bucket_output: OutputPathType | None
    """Main output bucket dataset in AFNI format."""
    cbucket_output: OutputPathType | None
    """Regression coefficients stored in a dataset."""
    iresp_output: OutputPathType | None
    """Estimated Impulse Response dataset."""
    fitts_output: OutputPathType | None
    """Fitted Time Series dataset in AFNI format."""
    x1d_file: OutputPathType | None
    """X-matrix output file in .1D format."""


def v_3d_deconvolve(
    input_dataset: InputPathType,
    mask_dataset: InputPathType | None = None,
    num_stimts: int | None = None,
    stim_file: str | None = None,
    stim_label: str | None = None,
    stim_base: bool = False,
    stim_times: str | None = None,
    iresp: str | None = None,
    fitts: str | None = None,
    fout: bool = False,
    tout: bool = False,
    bucket: str | None = None,
    cbucket: str | None = None,
    x1_d: str | None = None,
    jobs: int | None = None,
    runner: Runner | None = None,
) -> V3dDeconvolveOutputs:
    """
    Program to calculate the deconvolution of a measurement 3D+time dataset with a
    specified input stimulus time series.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Filename of 3D+time input dataset.
        mask_dataset: Filename of 3D mask dataset.
        num_stimts: Number of input stimulus time series.
        stim_file: Filename of kth time series input stimulus.
        stim_label: Label for kth input stimulus.
        stim_base: Kth input stimulus is part of the baseline model.
        stim_times: Deconvolution response model for kth stimulus.
        iresp: Prefix for 3D+time output dataset which will contain the kth\
            estimated impulse response.
        fitts: Prefix for 3D+time output dataset which will contain the (full\
            model) time series fit to the input data.
        fout: Flag to output the F-statistics for each stimulus.
        tout: Flag to output the t-statistics.
        bucket: Create one AFNI 'bucket' dataset containing various parameters\
            of interest.
        cbucket: Save the regression coefficients (no statistics) into a\
            dataset.
        x1_d: Save X matrix to a .xmat.1D (ASCII) file.
        jobs: Run the program with multiple jobs (sub-processes).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDeconvolveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DECONVOLVE_METADATA)
    cargs = []
    cargs.append("3dDeconvolve")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    if num_stimts is not None:
        cargs.extend([
            "-num_stimts",
            str(num_stimts)
        ])
    if stim_file is not None:
        cargs.extend([
            "-stim_file",
            stim_file
        ])
    if stim_label is not None:
        cargs.extend([
            "-stim_label",
            stim_label
        ])
    if stim_base:
        cargs.append("-stim_base")
    if stim_times is not None:
        cargs.extend([
            "-stim_times",
            stim_times
        ])
    if iresp is not None:
        cargs.extend([
            "-iresp",
            iresp
        ])
    if fitts is not None:
        cargs.extend([
            "-fitts",
            fitts
        ])
    if fout:
        cargs.append("-fout")
    if tout:
        cargs.append("-tout")
    if bucket is not None:
        cargs.extend([
            "-bucket",
            bucket
        ])
    if cbucket is not None:
        cargs.extend([
            "-cbucket",
            cbucket
        ])
    if x1_d is not None:
        cargs.extend([
            "-x1D",
            x1_d
        ])
    if jobs is not None:
        cargs.extend([
            "-jobs",
            str(jobs)
        ])
    ret = V3dDeconvolveOutputs(
        root=execution.output_file("."),
        bucket_output=execution.output_file(bucket + ".HEAD") if (bucket is not None) else None,
        cbucket_output=execution.output_file(cbucket + ".HEAD") if (cbucket is not None) else None,
        iresp_output=execution.output_file(iresp + ".HEAD") if (iresp is not None) else None,
        fitts_output=execution.output_file(fitts + ".HEAD") if (fitts is not None) else None,
        x1d_file=execution.output_file(x1_d + ".1D") if (x1_d is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDeconvolveOutputs",
    "V_3D_DECONVOLVE_METADATA",
    "v_3d_deconvolve",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_KERNEL_METADATA = Metadata(
    id="68541ec7748d8d13f5c268560fc3b05f625b4dae.boutiques",
    name="morph_kernel",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MorphKernelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_kernel(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    morph_kernel_output: OutputPathType
    """Output morphological kernel file"""


def morph_kernel(
    cube_side_length: float,
    sphere_radius: float,
    runner: Runner | None = None,
) -> MorphKernelOutputs:
    """
    Tool to generate morphological kernels.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        cube_side_length: Side length of the cube (e.g., 11).
        sphere_radius: Radius of the sphere (e.g., 5.5).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphKernelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_KERNEL_METADATA)
    cargs = []
    cargs.append("morph_kernel")
    cargs.append(str(cube_side_length))
    cargs.append(str(sphere_radius))
    ret = MorphKernelOutputs(
        root=execution.output_file("."),
        morph_kernel_output=execution.output_file("sphere[OUTPUT_PREFIX].ker"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_KERNEL_METADATA",
    "MorphKernelOutputs",
    "morph_kernel",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_CONNEC_VIS_METADATA = Metadata(
    id="3c0e03aae455fbd21d6ab5bd41865b6565e23556.boutiques",
    name="fat_proc_connec_vis",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcConnecVisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_connec_vis(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cmd_txt: OutputPathType
    """Command text file output"""
    tcat_file: OutputPathType
    """Concatenated ROI masks multibrick file from the -output_tcat flag"""
    tstat_file: OutputPathType
    """Single brick file from 3dTstat operation on the tcat dataset, produced by
    the -output_tstat flag"""


def fat_proc_connec_vis(
    in_rois: str,
    prefix: str,
    prefix_file: str | None = None,
    tsmoo_kpb: float | None = None,
    tsmoo_niter: float | None = None,
    iso_opt: str | None = None,
    trackid_no_or: bool = False,
    output_tcat: bool = False,
    output_tstat: bool = False,
    wdir: str | None = None,
    no_clean: bool = False,
    runner: Runner | None = None,
) -> FatProcConnecVisOutputs:
    """
    This program is for visualizing the volumetric output of tracking, mainly for
    the '-dump_rois ...' from 3dTrackID. It creates surface-ized views of the
    separate white matter connection maps (WMCs) which can be viewed simultaneously
    in 3D with SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_rois: List of separate files, each with a single ROI volume mask;\
            can include wildcards, etc. to specify the list.
        prefix: Directory to contain the output files: *cmd.txt and surface\
            files such as *.gii and *.niml.dset; the namebase of files within this\
            directory will be the default for the program, 'wmc'. The value PPP can\
            contain parts of a path in it.
        prefix_file: Prefix for the output files: *cmd.txt and surface files\
            such as *.gii and *.niml.dset; can include path steps; and can make one\
            level of a new directory. For example, if FFF were 'A/B', then the\
            program could make a new directory called 'A' if it didn't exist\
            already and populate it with individual files having the same prefix\
            'B'.
        tsmoo_kpb: 'KPB' parameter in IsoSurface program; default value is\
            0.01.
        tsmoo_niter: 'NITER' parameter in IsoSurface program; default value is\
            6.
        iso_opt: Input one of the 'iso* options' from IsoSurface program, such\
            as 'isorois+dsets', 'mergerois', etc. Quotations around the entry may\
            be needed, especially if something like the '-mergerois [LAB_OUT]'\
            route is being followed. Default: isorois+dsets.
        trackid_no_or: Use this option to have the program recognize the naming\
            convention of 3dTrackID output and to ignore the OR-logic ROIs,\
            including only the AND-logic (AKA pairwise) connections.
        output_tcat: Flag to output the multibrick file of concatenated ROI\
            masks; note that the [0]th brick will be all zeros (it is just a\
            placeholder). So, if there are N ROI maps concatenated, there will be\
            N+1 bricks in the output dataset, which has the name PPP_tcat.nii.gz.
        output_tstat: Flag to output the single brick file from the 3dTstat\
            operation on the tcat dataset. If there were N ROI maps concatenated,\
            then the largest value should be N. The output file's name will be\
            PPP_tstat.nii.gz.
        wdir: Working directory prefix. The format is '__WDIR_connec_vis_PPP',\
            where PPP is the input prefix.
        no_clean: Optional switch to NOT remove the working directory (default\
            is to remove the working directory).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcConnecVisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_CONNEC_VIS_METADATA)
    cargs = []
    cargs.append("fat_proc_connec_vis")
    cargs.append(in_rois)
    cargs.append(prefix)
    if prefix_file is not None:
        cargs.extend([
            "-prefix_file",
            prefix_file
        ])
    if tsmoo_kpb is not None:
        cargs.extend([
            "-tsmoo_kpb",
            str(tsmoo_kpb)
        ])
    if tsmoo_niter is not None:
        cargs.extend([
            "-tsmoo_niter",
            str(tsmoo_niter)
        ])
    if iso_opt is not None:
        cargs.extend([
            "-iso_opt",
            iso_opt
        ])
    if trackid_no_or:
        cargs.append("-trackid_no_or")
    if output_tcat:
        cargs.append("-output_tcat")
    if output_tstat:
        cargs.append("-output_tstat")
    if wdir is not None:
        cargs.extend([
            "-wdir",
            wdir
        ])
    if no_clean:
        cargs.append("-no_clean")
    ret = FatProcConnecVisOutputs(
        root=execution.output_file("."),
        cmd_txt=execution.output_file(prefix + "_cmd.txt"),
        tcat_file=execution.output_file(prefix + "_tcat.nii.gz"),
        tstat_file=execution.output_file(prefix + "_tstat.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_CONNEC_VIS_METADATA",
    "FatProcConnecVisOutputs",
    "fat_proc_connec_vis",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EPIDEWARP_FSL_METADATA = Metadata(
    id="0b6f576dc06a529efd6bb20065d0ee4307b24409.boutiques",
    name="epidewarp.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class EpidewarpFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `epidewarp_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    vsm_output: OutputPathType
    """Voxel Shift Map output"""
    exfdw_output: OutputPathType | None
    """Dewarped example func volume"""
    epidw_output: OutputPathType | None
    """Dewarped EPI volume"""
    vsmmag_output: OutputPathType | None
    """Voxel shift map in mag space output"""


def epidewarp_fsl(
    vsm: str,
    mag: InputPathType | None = None,
    dph: InputPathType | None = None,
    ph: InputPathType | None = None,
    complex_: list[float] | None = None,
    exf: InputPathType | None = None,
    epi: InputPathType | None = None,
    tediff: float | None = None,
    esp: float | None = None,
    perev: bool = False,
    sigma: float | None = None,
    vsm_fwhm: float | None = None,
    vsmmag: str | None = None,
    exfdw: str | None = None,
    epidw: str | None = None,
    nomagexfreg: bool = False,
    head: bool = False,
    tmpdir: str | None = None,
    log: str | None = None,
    nocleanup: bool = False,
    cleanup: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> EpidewarpFslOutputs:
    """
    Front end for FSL's PRELUDE and FUGUE programs to correct B0 distortion in EPI
    scans.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vsm: Voxel shift map (required).
        mag: B0 magnitude volume.
        dph: B0 phase difference volume.
        ph: B0 phase volume.
        complex_: B0 map in complex values: real1 imag1 real2 imag2.
        exf: Example func volume.
        epi: EPI volume to unwarp.
        tediff: Difference in B0 field map TEs.
        esp: EPI echo spacing.
        perev: Assume reversed phase encode direction.
        sigma: 2D spatial gaussian smoothing stddev (default 2mm).
        vsm_fwhm: Allows VSM to be extended outside of the mask.
        vsmmag: Voxel shift map in mag space.
        exfdw: Dewarped example func volume.
        epidw: Dewarped EPI volume.
        nomagexfreg: Assume mag and exf are in register.
        head: Mask to head instead of brain.
        tmpdir: Save intermediate results here.
        log: Use logfile instead of default.
        nocleanup: Do not delete tmpdir.
        cleanup: Force deletion of tmpdir.
        debug: Prints copious amounts to the screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EpidewarpFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EPIDEWARP_FSL_METADATA)
    cargs = []
    cargs.append("epidewarp.fsl")
    if mag is not None:
        cargs.extend([
            "--mag",
            execution.input_file(mag)
        ])
    if dph is not None:
        cargs.extend([
            "--dph",
            execution.input_file(dph)
        ])
    if ph is not None:
        cargs.extend([
            "--ph",
            execution.input_file(ph)
        ])
    if complex_ is not None:
        cargs.extend([
            "--complex",
            *map(str, complex_)
        ])
    if exf is not None:
        cargs.extend([
            "--exf",
            execution.input_file(exf)
        ])
    if epi is not None:
        cargs.extend([
            "--epi",
            execution.input_file(epi)
        ])
    if tediff is not None:
        cargs.extend([
            "--tediff",
            str(tediff)
        ])
    if esp is not None:
        cargs.extend([
            "--esp",
            str(esp)
        ])
    if perev:
        cargs.append("--perev")
    if sigma is not None:
        cargs.extend([
            "--sigma",
            str(sigma)
        ])
    if vsm_fwhm is not None:
        cargs.extend([
            "--vsm-fwhm",
            str(vsm_fwhm)
        ])
    cargs.extend([
        "--vsm",
        vsm
    ])
    if vsmmag is not None:
        cargs.extend([
            "--vsmmag",
            vsmmag
        ])
    if exfdw is not None:
        cargs.extend([
            "--exfdw",
            exfdw
        ])
    if epidw is not None:
        cargs.extend([
            "--epidw",
            epidw
        ])
    if nomagexfreg:
        cargs.append("--nomagexfreg")
    if head:
        cargs.append("--head")
    if tmpdir is not None:
        cargs.extend([
            "--tmpdir",
            tmpdir
        ])
    if log is not None:
        cargs.extend([
            "--log",
            log
        ])
    if nocleanup:
        cargs.append("--nocleanup")
    if cleanup:
        cargs.append("--cleanup")
    if debug:
        cargs.append("--debug")
    ret = EpidewarpFslOutputs(
        root=execution.output_file("."),
        vsm_output=execution.output_file(vsm + ".nii.gz"),
        exfdw_output=execution.output_file(exfdw + ".nii.gz") if (exfdw is not None) else None,
        epidw_output=execution.output_file(epidw + ".nii.gz") if (epidw is not None) else None,
        vsmmag_output=execution.output_file(vsmmag + ".nii.gz") if (vsmmag is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EPIDEWARP_FSL_METADATA",
    "EpidewarpFslOutputs",
    "epidewarp_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_DISPLACEMENT_FIELD_METADATA = Metadata(
    id="802911687fe6024ba5b40503dd2ac46f0ca9b56b.boutiques",
    name="CreateDisplacementField",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class CreateDisplacementFieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_displacement_field(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_displacement_field: OutputPathType
    """The generated itkImage of itkVector pixels representing the displacement
    field."""


def create_displacement_field(
    image_dimension: int,
    enforce_zero_boundary_flag: typing.Literal[0, 1],
    component_images: list[InputPathType],
    output_image: InputPathType,
    runner: Runner | None = None,
) -> CreateDisplacementFieldOutputs:
    """
    Create an itkImage of itkVector pixels (NOT an itkVectorImage), using each
    scalar input component image for each vector component. An itkImage of
    itkVectors is the standard type for displacement fields in ITK. All component
    images (up to 8) are assumed to have the same size, offset, origin, and spacing.
    The 'EnforceZeroBoundaryFlag' option will create zero-valued vectors along the
    borders when enabled (pass 1), and is recommended for better displacement field
    behavior.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimension of the image, typically 2 or 3.
        enforce_zero_boundary_flag: Create zero-valued vectors along the\
            borders when enabled (pass 1), recommended for better displacement\
            field behavior.
        component_images: Input component images, each used for a vector\
            component. All component images must have the same size, offset,\
            origin, and spacing.
        output_image: The output displacement field image with itkVector\
            pixels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateDisplacementFieldOutputs`).
    """
    if not (1 <= len(component_images) <= 8): 
        raise ValueError(f"Length of 'component_images' must be between 1 and 8 but was {len(component_images)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_DISPLACEMENT_FIELD_METADATA)
    cargs = []
    cargs.append("CreateDisplacementField")
    cargs.append(str(image_dimension))
    cargs.append(str(enforce_zero_boundary_flag))
    cargs.extend([execution.input_file(f) for f in component_images])
    cargs.append(execution.input_file(output_image))
    ret = CreateDisplacementFieldOutputs(
        root=execution.output_file("."),
        output_displacement_field=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_DISPLACEMENT_FIELD_METADATA",
    "CreateDisplacementFieldOutputs",
    "create_displacement_field",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_MERGE_METADATA = Metadata(
    id="23abeff64ad6c7ec293da11e92c329b37b1711f7.boutiques",
    name="label-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class LabelMergeUpTo:
    """
    use an inclusive range of columns.
    """
    last_column: str
    """the number or name of the last column to include"""
    opt_reverse: bool = False
    """use the range in reverse order"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-up-to")
        cargs.append(self.last_column)
        if self.opt_reverse:
            cargs.append("-reverse")
        return cargs


@dataclasses.dataclass
class LabelMergeColumn:
    """
    select a single column to use.
    """
    column: str
    """the column number or name"""
    up_to: LabelMergeUpTo | None = None
    """use an inclusive range of columns"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-column")
        cargs.append(self.column)
        if self.up_to is not None:
            cargs.extend(self.up_to.run(execution))
        return cargs


@dataclasses.dataclass
class LabelMergeLabel:
    """
    specify an input label.
    """
    label_in: InputPathType
    """a label file to use columns from"""
    column: list[LabelMergeColumn] | None = None
    """select a single column to use"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-label")
        cargs.append(execution.input_file(self.label_in))
        if self.column is not None:
            cargs.extend([a for c in [s.run(execution) for s in self.column] for a in c])
        return cargs


class LabelMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_merge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label"""


def label_merge(
    label_out: str,
    label: list[LabelMergeLabel] | None = None,
    runner: Runner | None = None,
) -> LabelMergeOutputs:
    """
    Merge label files into a new file.
    
    Takes one or more label files and constructs a new label file by
    concatenating columns from them. The input files must have the same number
    of vertices and the same structure.
    
    Example: wb_command -label-merge out.label.gii -label first.label.gii
    -column 1 -label second.label.gii
    
    This example would take the first column from first.label.gii and all
    subvolumes from second.label.gii, and write these to out.label.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_out: the output label.
        label: specify an input label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_MERGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-merge")
    cargs.append(label_out)
    if label is not None:
        cargs.extend([a for c in [s.run(execution) for s in label] for a in c])
    ret = LabelMergeOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(label_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_MERGE_METADATA",
    "LabelMergeColumn",
    "LabelMergeLabel",
    "LabelMergeOutputs",
    "LabelMergeUpTo",
    "label_merge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLMEANTS_METADATA = Metadata(
    id="fcc95512e4d985215019fd1ae002fbea7f289d21.boutiques",
    name="fslmeants",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslmeantsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslmeants(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_text_matrix: OutputPathType | None
    """Output text matrix from fslmeants"""


def fslmeants(
    input_image: InputPathType,
    output: str | None = None,
    mask: InputPathType | None = None,
    coordinates: list[float] | None = None,
    usemm_flag: bool = False,
    showall_flag: bool = False,
    eigenv_flag: bool = False,
    eigenvariates_order: float | None = None,
    no_bin_flag: bool = False,
    label_image: InputPathType | None = None,
    transpose_flag: bool = False,
    weighted_mean_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> FslmeantsOutputs:
    """
    Prints average timeseries (intensities) to the screen (or saves to a file).
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Input 4D image.
        output: Output text matrix.
        mask: Input 3D mask.
        coordinates: Requested spatial coordinate (instead of mask). Must have\
            exactly three numerical entries in the list (3-vector).
        usemm_flag: Use mm instead of voxel coordinates (for -c option).
        showall_flag: Show all voxel time series (within mask) instead of\
            averaging.
        eigenv_flag: Calculate Eigenvariate(s) instead of mean (output will\
            have 0 mean).
        eigenvariates_order: Select number of Eigenvariates (default 1).
        no_bin_flag: Do not binarise the mask for calculation of Eigenvariates.
        label_image: Input 3D label image (generate separate mean for each\
            integer label value - cannot be used with showall).
        transpose_flag: Output results in transpose format (one row per\
            voxel/mean).
        weighted_mean_flag: Output weighted mean, using mask values as weights,\
            and exit.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslmeantsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLMEANTS_METADATA)
    cargs = []
    cargs.append("fslmeants")
    cargs.extend([
        "-i",
        execution.input_file(input_image)
    ])
    if output is not None:
        cargs.extend([
            "-o",
            output
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if coordinates is not None:
        cargs.extend([
            "-c",
            *map(str, coordinates)
        ])
    if usemm_flag:
        cargs.append("--usemm")
    if showall_flag:
        cargs.append("--showall")
    if eigenv_flag:
        cargs.append("--eig")
    if eigenvariates_order is not None:
        cargs.extend([
            "--order",
            str(eigenvariates_order)
        ])
    if no_bin_flag:
        cargs.append("--no_bin")
    if label_image is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_image)
        ])
    if transpose_flag:
        cargs.append("--transpose")
    if weighted_mean_flag:
        cargs.append("-w")
    if verbose_flag:
        cargs.append("-v")
    ret = FslmeantsOutputs(
        root=execution.output_file("."),
        output_text_matrix=execution.output_file(output) if (output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLMEANTS_METADATA",
    "FslmeantsOutputs",
    "fslmeants",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_COPY_EXTENSIONS_METADATA = Metadata(
    id="862abf7914f0edcebc84a7fc1d70c95d8938e52d.boutiques",
    name="volume-copy-extensions",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeCopyExtensionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_copy_extensions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_copy_extensions(
    data_volume: InputPathType,
    extension_volume: InputPathType,
    volume_out: str,
    opt_drop_unknown: bool = False,
    runner: Runner | None = None,
) -> VolumeCopyExtensionsOutputs:
    """
    Copy extended data to another volume file.
    
    This command copies the information in a volume file that isn't a critical
    part of the standard header or data matrix, e.g. map names, palette
    settings, label tables. If -drop-unknown is not specified, it also copies
    similar kinds of information set by other software.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_volume: the volume file containing the voxel data to use.
        extension_volume: the volume file containing the extensions to use.
        volume_out: the output volume.
        opt_drop_unknown: don't copy extensions that workbench doesn't\
            understand.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCopyExtensionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_COPY_EXTENSIONS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-copy-extensions")
    cargs.append(execution.input_file(data_volume))
    cargs.append(execution.input_file(extension_volume))
    cargs.append(volume_out)
    if opt_drop_unknown:
        cargs.append("-drop-unknown")
    ret = VolumeCopyExtensionsOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_COPY_EXTENSIONS_METADATA",
    "VolumeCopyExtensionsOutputs",
    "volume_copy_extensions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IS_LTA_METADATA = Metadata(
    id="566d24838e7313b28a22f432de359c9b90571b0e.boutiques",
    name="IsLTA",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsLtaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `is_lta(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """File containing 1 if the candidate file is an LTA, otherwise 0"""


def is_lta(
    candidate_file: InputPathType,
    outfile: str,
    runner: Runner | None = None,
) -> IsLtaOutputs:
    """
    Determines if a given file is an LTA (Linear Transform Array) file. Outputs 1 if
    true, otherwise outputs 0.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        candidate_file: Candidate file to check if it is an LTA.
        outfile: Output file to write the result.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsLtaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IS_LTA_METADATA)
    cargs = []
    cargs.append("IsLTA")
    cargs.extend([
        "--r",
        execution.input_file(candidate_file)
    ])
    cargs.extend([
        "--o",
        outfile
    ])
    ret = IsLtaOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(outfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IS_LTA_METADATA",
    "IsLtaOutputs",
    "is_lta",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FS_INSTALL_MCR_METADATA = Metadata(
    id="3368d00255c0d7e5b75947a021056a82a28657ea.boutiques",
    name="fs_install_mcr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FsInstallMcrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fs_install_mcr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fs_install_mcr(
    mcr_version: str,
    runner: Runner | None = None,
) -> FsInstallMcrOutputs:
    """
    MCR installation tool for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mcr_version: Specify the MATLAB Compiler Runtime (MCR) version to\
            install.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsInstallMcrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FS_INSTALL_MCR_METADATA)
    cargs = []
    cargs.append("fs_install_mcr")
    cargs.append(mcr_version)
    ret = FsInstallMcrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FS_INSTALL_MCR_METADATA",
    "FsInstallMcrOutputs",
    "fs_install_mcr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMCALC_METADATA = Metadata(
    id="619429e3eb3a18d69af5e0d47edb5f5289323a19.boutiques",
    name="imcalc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imcalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType | None
    """Output image file produced after applying the expression to input
    images"""


def imcalc(
    expression: str,
    datum_type: str | None = None,
    image_inputs: list[InputPathType] | None = None,
    output_name: str | None = None,
    runner: Runner | None = None,
) -> ImcalcOutputs:
    """
    Tool for arithmetic operations on 2D images, pixel-by-pixel.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        expression: Apply the expression within quotes to the input images, one\
            voxel at a time, to produce the output image. (e.g., "sqrt(a*b)" to\
            compute the geometric mean).
        datum_type: Coerce the output data to be stored as the given type:\
            byte, short, or float. Default is the datum of the first input image on\
            the command line.
        image_inputs: Read image 'dname' and call the voxel values 'a' in the\
            expression. 'a' may be any letter from 'a' to 'z'. If some letter name\
            is used in the expression but not present in one of the image options\
            here, then that variable is set to 0.
        output_name: Use 'name' for the output image filename. Default is\
            'imcalc.out'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMCALC_METADATA)
    cargs = []
    cargs.append("imcalc")
    if datum_type is not None:
        cargs.extend([
            "-datum type",
            datum_type
        ])
    if image_inputs is not None:
        cargs.extend([
            "-a",
            *[execution.input_file(f) for f in image_inputs]
        ])
    cargs.extend([
        "-expr",
        expression
    ])
    if output_name is not None:
        cargs.extend([
            "-output",
            output_name
        ])
    ret = ImcalcOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(output_name) if (output_name is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMCALC_METADATA",
    "ImcalcOutputs",
    "imcalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ALLINEATE_METADATA = Metadata(
    id="9e9b34eca4cf79e9ab56b274a89a3cd8dc932bed.boutiques",
    name="3dAllineate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAllineateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_allineate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_brik: OutputPathType
    """Output dataset brick file"""
    out_head: OutputPathType
    """Output dataset head file"""
    out_param_save: OutputPathType | None
    """File holding saved warp parameters"""
    out_matrix_save: OutputPathType | None
    """File holding saved matrix transformations"""


def v_3d_allineate(
    source: InputPathType,
    prefix: str,
    base: InputPathType | None = None,
    param_save: str | None = None,
    param_apply: str | None = None,
    matrix_save: str | None = None,
    matrix_apply: str | None = None,
    cost: str | None = None,
    interp: str | None = None,
    final: str | None = None,
    nmatch: float | None = None,
    nopad: bool = False,
    verbose: bool = False,
    quiet: bool = False,
    runner: Runner | None = None,
) -> V3dAllineateOutputs:
    """
    Program to align one dataset (the 'source') to a 'base' dataset using an affine
    (matrix) transformation of space.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        source: Source dataset file.
        prefix: Output prefix.
        base: Base dataset file.
        param_save: Save the warp parameters in ASCII (.1D) format into file.
        param_apply: Read warp parameters from file and apply them to the\
            source dataset.
        matrix_save: Save the transformation matrix for each sub-brick into\
            file.
        matrix_apply: Use the matrices in file to define the spatial\
            transformations to be applied.
        cost: Defines the 'cost' function that defines the matching between the\
            source and the base.
        interp: Defines interpolation method to use during matching process.
        final: Defines the interpolation mode used to create the output dataset.
        nmatch: Use at most 'nnn' scattered points to match the datasets.
        nopad: Do not use zero-padding on the base image.
        verbose: Print out verbose progress reports.
        quiet: Don't print out verbose stuff.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAllineateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ALLINEATE_METADATA)
    cargs = []
    cargs.append("3dAllineate")
    cargs.append(execution.input_file(source))
    if base is not None:
        cargs.extend([
            "-base",
            execution.input_file(base)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if param_save is not None:
        cargs.extend([
            "-1Dparam_save",
            param_save
        ])
    if param_apply is not None:
        cargs.extend([
            "-1Dparam_apply",
            param_apply
        ])
    if matrix_save is not None:
        cargs.extend([
            "-1Dmatrix_save",
            matrix_save
        ])
    if matrix_apply is not None:
        cargs.extend([
            "-1Dmatrix_apply",
            matrix_apply
        ])
    if cost is not None:
        cargs.extend([
            "-cost",
            cost
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if final is not None:
        cargs.extend([
            "-final",
            final
        ])
    if nmatch is not None:
        cargs.extend([
            "-nmatch",
            str(nmatch)
        ])
    if nopad:
        cargs.append("-nopad")
    if verbose:
        cargs.append("-verb")
    if quiet:
        cargs.append("-quiet")
    ret = V3dAllineateOutputs(
        root=execution.output_file("."),
        out_brik=execution.output_file(prefix + "+orig.BRIK"),
        out_head=execution.output_file(prefix + "+orig.HEAD"),
        out_param_save=execution.output_file(param_save) if (param_save is not None) else None,
        out_matrix_save=execution.output_file(matrix_save) if (matrix_save is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAllineateOutputs",
    "V_3D_ALLINEATE_METADATA",
    "v_3d_allineate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_T1_AUTO_ESTIMATE_ALVEUS_ML_METADATA = Metadata(
    id="43b0001ab86e4ffd97c64d3a223a099dafddc2e9.boutiques",
    name="segmentSubjectT1_autoEstimateAlveusML",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectT1AutoEstimateAlveusMlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_t1_auto_estimate_alveus_ml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """The file containing segmented MRI data."""


def segment_subject_t1_auto_estimate_alveus_ml(
    t1_file: InputPathType,
    output_folder: str,
    runner: Runner | None = None,
) -> SegmentSubjectT1AutoEstimateAlveusMlOutputs:
    """
    A tool that segments T1-weighted MRI data and automatically estimates the
    Alveus.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_file: Input T1-weighted MRI file to be segmented.
        output_folder: Path to the folder where the outputs will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectT1AutoEstimateAlveusMlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_T1_AUTO_ESTIMATE_ALVEUS_ML_METADATA)
    cargs = []
    cargs.append("segmentSubjectT1_autoEstimateAlveusML")
    cargs.append(execution.input_file(t1_file))
    cargs.append(output_folder)
    ret = SegmentSubjectT1AutoEstimateAlveusMlOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output_folder + "/segmented_output.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_T1_AUTO_ESTIMATE_ALVEUS_ML_METADATA",
    "SegmentSubjectT1AutoEstimateAlveusMlOutputs",
    "segment_subject_t1_auto_estimate_alveus_ml",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FDR_METADATA = Metadata(
    id="c6df1fc3c682e8d10bc8100c6ca38bb1d5015a85.boutiques",
    name="mri_fdr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_corrected: OutputPathType
    """Output after applying FDR correction"""
    output_threshold: OutputPathType
    """Threshold written to text file"""


def mri_fdr(
    input_files: list[str],
    fdr_value: float,
    default_frame: int | None = None,
    positive_only: bool = False,
    negative_only: bool = False,
    all_voxels: bool = False,
    raw_p_values: bool = False,
    threshold_file: str | None = None,
    debug: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> MriFdrOutputs:
    """
    A program that performs False Discovery Rate correction.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input source volume or surface overlay. Specify mask,\
            output, and frame as needed.
        fdr_value: FDR value between 0 and 1, typically .05.
        default_frame: Use input frame when not specifying frame in --i.
        positive_only: Only consider positive voxels.
        negative_only: Only consider negative voxels.
        all_voxels: Consider all voxels regardless of sign (default).
        raw_p_values: Input is raw p-values, not -log10(p).
        threshold_file: Write threshold to text file.
        debug: Turn on debugging.
        check_options: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFdrOutputs`).
    """
    if not (1 <= len(input_files)): 
        raise ValueError(f"Length of 'input_files' must be greater than 1 but was {len(input_files)}")
    if not (0 <= fdr_value <= 1): 
        raise ValueError(f"'fdr_value' must be between 0 <= x <= 1 but was {fdr_value}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FDR_METADATA)
    cargs = []
    cargs.append("mri_fdr")
    cargs.extend([
        "--i",
        *input_files
    ])
    cargs.extend([
        "--fdr",
        str(fdr_value)
    ])
    if default_frame is not None:
        cargs.extend([
            "--f",
            str(default_frame)
        ])
    if positive_only:
        cargs.append("--pos")
    if negative_only:
        cargs.append("--neg")
    if all_voxels:
        cargs.append("--abs")
    if raw_p_values:
        cargs.append("--no-log10p")
    if threshold_file is not None:
        cargs.extend([
            "--thfile",
            threshold_file
        ])
    if debug:
        cargs.append("--debug")
    if check_options:
        cargs.append("--checkopts")
    ret = MriFdrOutputs(
        root=execution.output_file("."),
        output_corrected=execution.output_file("<output>.mgh"),
        output_threshold=execution.output_file("<output>_threshold.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FDR_METADATA",
    "MriFdrOutputs",
    "mri_fdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XCORR_METADATA = Metadata(
    id="9e4522b49e6cabe069fc758dd70b99c8feb9830e.boutiques",
    name="xcorr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class XcorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xcorr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_xcorrfile: OutputPathType
    """Output xcorr file"""
    log_output: OutputPathType | None
    """Log of xcorr execution"""


def xcorr(
    input1: InputPathType,
    input2: InputPathType,
    output: str,
    log_file: str | None = None,
    tmp_dir: str | None = None,
    no_cleanup: bool = False,
    runner: Runner | None = None,
) -> XcorrOutputs:
    """
    Computes the voxel-for-voxel correlation coefficient between two volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input1: First input volume file.
        input2: Second input volume file.
        output: Output xcorr file.
        log_file: Log file.
        tmp_dir: Temporary directory.
        no_cleanup: Prevent cleanup of temporary files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XcorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XCORR_METADATA)
    cargs = []
    cargs.append("xcorr")
    cargs.extend([
        "--i1",
        execution.input_file(input1)
    ])
    cargs.extend([
        "--i2",
        execution.input_file(input2)
    ])
    cargs.extend([
        "--o",
        output
    ])
    if log_file is not None:
        cargs.extend([
            "--log",
            log_file
        ])
    if tmp_dir is not None:
        cargs.extend([
            "--tmp",
            tmp_dir
        ])
    if no_cleanup:
        cargs.append("--no-cleanup")
    ret = XcorrOutputs(
        root=execution.output_file("."),
        out_xcorrfile=execution.output_file(output),
        log_output=execution.output_file(log_file) if (log_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XCORR_METADATA",
    "XcorrOutputs",
    "xcorr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_CALC_METADATA = Metadata(
    id="0f04865341178eeb624695b7ff33be523bb926b5.boutiques",
    name="mris_calc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisCalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_calc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_curv_file: OutputPathType | None
    """The resulting FreeSurfer curvature overlay or volume file."""


def mris_calc(
    input_file1: InputPathType,
    action: str,
    input_file2_or_float: InputPathType | None = None,
    output_file: str | None = None,
    label_file: InputPathType | None = None,
    verbosity: str | None = None,
    runner: Runner | None = None,
) -> MrisCalcOutputs:
    """
    Simple calculator that operates on FreeSurfer curvatures and volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file1: The name of a FreeSurfer curvature overlay (e.g., rh.curv)\
            or volume file (e.g., orig.mgz).
        action: Mathematical action to perform on the input file(s), written as\
            a text string.
        input_file2_or_float: The second input for the calculation. Can be a\
            file (e.g., rh.thickness) or a float number if the file does not exist.
        output_file: Specify the output file name for the result of the\
            calculation.
        label_file: Constrain the calculation to vertices defined in the\
            FreeSurfer label file.
        verbosity: Set the verbosity of the program.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisCalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_CALC_METADATA)
    cargs = []
    cargs.append("mris_calc")
    cargs.append(execution.input_file(input_file1))
    cargs.append(action)
    if input_file2_or_float is not None:
        cargs.append(execution.input_file(input_file2_or_float))
    if output_file is not None:
        cargs.extend([
            "--output",
            output_file
        ])
    if label_file is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_file)
        ])
    if verbosity is not None:
        cargs.extend([
            "--verbosity",
            verbosity
        ])
    ret = MrisCalcOutputs(
        root=execution.output_file("."),
        output_curv_file=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_CALC_METADATA",
    "MrisCalcOutputs",
    "mris_calc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_ORIENT_SIGN_METADATA = Metadata(
    id="15cd2787067ab0ba26eeeccbc4360543d4f091c5.boutiques",
    name="@AfniOrientSign",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniOrientSignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_orient_sign(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output file containing the orientation signs of the dataset"""


def v__afni_orient_sign(
    infile: InputPathType,
    runner: Runner | None = None,
) -> VAfniOrientSignOutputs:
    """
    A tool within the AFNI suite to determine the orientation signs of datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Input image file to determine orientation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniOrientSignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_ORIENT_SIGN_METADATA)
    cargs = []
    cargs.append("@AfniOrientSign")
    cargs.extend([
        "-orient",
        execution.input_file(infile)
    ])
    ret = VAfniOrientSignOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(pathlib.Path(infile).name + "_orient.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniOrientSignOutputs",
    "V__AFNI_ORIENT_SIGN_METADATA",
    "v__afni_orient_sign",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_WEIGHTED_STATS_METADATA = Metadata(
    id="18f091ded19df25622a8ba5fd28dcde188252609.boutiques",
    name="metric-weighted-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricWeightedStatsRoi:
    """
    only consider data inside an roi.
    """
    roi_metric: InputPathType
    """the roi, as a metric file"""
    opt_match_maps: bool = False
    """each column of input uses the corresponding column from the roi file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-roi")
        cargs.append(execution.input_file(self.roi_metric))
        if self.opt_match_maps:
            cargs.append("-match-maps")
        return cargs


@dataclasses.dataclass
class MetricWeightedStatsStdev:
    """
    compute weighted standard deviation.
    """
    opt_sample: bool = False
    """estimate population stdev from the sample"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-stdev")
        if self.opt_sample:
            cargs.append("-sample")
        return cargs


class MetricWeightedStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_weighted_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metric_weighted_stats(
    metric_in: InputPathType,
    opt_area_surface_area_surface: InputPathType | None = None,
    opt_weight_metric_weight_metric: InputPathType | None = None,
    opt_column_column: str | None = None,
    roi: MetricWeightedStatsRoi | None = None,
    opt_mean: bool = False,
    stdev: MetricWeightedStatsStdev | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> MetricWeightedStatsOutputs:
    """
    Weighted spatial statistics on a metric file.
    
    For each column of the input, a line of text is printed, resulting from the
    specified operation. You must specify exactly one of -area-surface or
    -weight-metric. Use -column to only give output for a single column. If the
    -roi option is used without -match-maps, then each line will contain as many
    numbers as there are maps in the ROI file, separated by tab characters.
    Exactly one of -mean, -stdev, -percentile or -sum must be specified.
    
    Using -sum with -area-surface (or -weight-metric with a metric containing
    similar data) is equivalent to integrating with respect to surface area. For
    example, if you want to find the surface area within an roi, do this:
    
    $ wb_command -metric-weighted-stats roi.func.gii -sum -area-surface
    midthickness.surf.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_in: the input metric.
        opt_area_surface_area_surface: use vertex areas as weights: the surface\
            to use for vertex areas.
        opt_weight_metric_weight_metric: use weights from a metric file: metric\
            file containing the weights.
        opt_column_column: only display output for one column: the column\
            number or name.
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricWeightedStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_WEIGHTED_STATS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-weighted-stats")
    cargs.append(execution.input_file(metric_in))
    if opt_area_surface_area_surface is not None:
        cargs.extend([
            "-area-surface",
            execution.input_file(opt_area_surface_area_surface)
        ])
    if opt_weight_metric_weight_metric is not None:
        cargs.extend([
            "-weight-metric",
            execution.input_file(opt_weight_metric_weight_metric)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if roi is not None:
        cargs.extend(roi.run(execution))
    if opt_mean:
        cargs.append("-mean")
    if stdev is not None:
        cargs.extend(stdev.run(execution))
    if opt_percentile_percent is not None:
        cargs.extend([
            "-percentile",
            str(opt_percentile_percent)
        ])
    if opt_sum:
        cargs.append("-sum")
    if opt_show_map_name:
        cargs.append("-show-map-name")
    ret = MetricWeightedStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_WEIGHTED_STATS_METADATA",
    "MetricWeightedStatsOutputs",
    "MetricWeightedStatsRoi",
    "MetricWeightedStatsStdev",
    "metric_weighted_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_RESAMPLE_DCONN_MEMORY_METADATA = Metadata(
    id="6897a244659820e737362b7b9d26217d4c4a2122.boutiques",
    name="cifti-resample-dconn-memory",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiResampleDconnMemoryWeighted:
    """
    use weighted dilation (default).
    """
    opt_exponent_exponent: float | None = None
    """specify exponent in weighting function: exponent 'n' to use in (1 /
    (distance ^ n)) as the weighting function (default 7)"""
    opt_legacy_cutoff: bool = False
    """use v1.3.2 logic for the kernel cutoff"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-weighted")
        if self.opt_exponent_exponent is not None:
            cargs.extend([
                "-exponent",
                str(self.opt_exponent_exponent)
            ])
        if self.opt_legacy_cutoff:
            cargs.append("-legacy-cutoff")
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryVolumePredilate:
    """
    dilate the volume components before resampling.
    """
    dilate_mm: float
    """distance, in mm, to dilate"""
    opt_nearest: bool = False
    """use nearest value dilation"""
    weighted: CiftiResampleDconnMemoryWeighted | None = None
    """use weighted dilation (default)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-predilate")
        cargs.append(str(self.dilate_mm))
        if self.opt_nearest:
            cargs.append("-nearest")
        if self.weighted is not None:
            cargs.extend(self.weighted.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryWeighted_:
    """
    use weighted dilation (default).
    """
    opt_exponent_exponent: float | None = None
    """specify exponent in weighting function: exponent 'n' to use in (area /
    (distance ^ n)) as the weighting function (default 6)"""
    opt_legacy_cutoff: bool = False
    """use v1.3.2 logic for the kernel cutoff"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-weighted")
        if self.opt_exponent_exponent is not None:
            cargs.extend([
                "-exponent",
                str(self.opt_exponent_exponent)
            ])
        if self.opt_legacy_cutoff:
            cargs.append("-legacy-cutoff")
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemorySurfacePostdilate:
    """
    dilate the surface components after resampling.
    """
    dilate_mm: float
    """distance, in mm, to dilate"""
    opt_nearest: bool = False
    """use nearest value dilation"""
    opt_linear: bool = False
    """use linear dilation"""
    weighted: CiftiResampleDconnMemoryWeighted_ | None = None
    """use weighted dilation (default)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface-postdilate")
        cargs.append(str(self.dilate_mm))
        if self.opt_nearest:
            cargs.append("-nearest")
        if self.opt_linear:
            cargs.append("-linear")
        if self.weighted is not None:
            cargs.extend(self.weighted.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryFlirt:
    """
    MUST be used if affine is a flirt affine.
    """
    source_volume: str
    """the source volume used when generating the affine"""
    target_volume: str
    """the target volume used when generating the affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-flirt")
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryAffine:
    """
    use an affine transformation on the volume components.
    """
    affine_file: str
    """the affine file to use"""
    flirt: CiftiResampleDconnMemoryFlirt | None = None
    """MUST be used if affine is a flirt affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-affine")
        cargs.append(self.affine_file)
        if self.flirt is not None:
            cargs.extend(self.flirt.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryWarpfield:
    """
    use a warpfield on the volume components.
    """
    warpfield: str
    """the warpfield to use"""
    opt_fnirt_source_volume: str | None = None
    """MUST be used if using a fnirt warpfield: the source volume used when
    generating the warpfield"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-warpfield")
        cargs.append(self.warpfield)
        if self.opt_fnirt_source_volume is not None:
            cargs.extend([
                "-fnirt",
                self.opt_fnirt_source_volume
            ])
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryLeftAreaSurfs:
    """
    specify left surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant left anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant left anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryLeftAreaMetrics:
    """
    specify left vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryLeftSpheres:
    """
    specify spheres for left surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current left surface"""
    new_sphere: InputPathType
    """a sphere with the new left mesh that is in register with the current
    sphere"""
    left_area_surfs: CiftiResampleDconnMemoryLeftAreaSurfs | None = None
    """specify left surfaces to do vertex area correction based on"""
    left_area_metrics: CiftiResampleDconnMemoryLeftAreaMetrics | None = None
    """specify left vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.left_area_surfs is not None:
            cargs.extend(self.left_area_surfs.run(execution))
        if self.left_area_metrics is not None:
            cargs.extend(self.left_area_metrics.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryRightAreaSurfs:
    """
    specify right surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant right anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant right anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryRightAreaMetrics:
    """
    specify right vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryRightSpheres:
    """
    specify spheres for right surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current right surface"""
    new_sphere: InputPathType
    """a sphere with the new right mesh that is in register with the current
    sphere"""
    right_area_surfs: CiftiResampleDconnMemoryRightAreaSurfs | None = None
    """specify right surfaces to do vertex area correction based on"""
    right_area_metrics: CiftiResampleDconnMemoryRightAreaMetrics | None = None
    """specify right vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.right_area_surfs is not None:
            cargs.extend(self.right_area_surfs.run(execution))
        if self.right_area_metrics is not None:
            cargs.extend(self.right_area_metrics.run(execution))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryCerebellumAreaSurfs:
    """
    specify cerebellum surfaces to do vertex area correction based on.
    """
    current_area: InputPathType
    """a relevant cerebellum anatomical surface with current mesh"""
    new_area: InputPathType
    """a relevant cerebellum anatomical surface with new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-area-surfs")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryCerebellumAreaMetrics:
    """
    specify cerebellum vertex area metrics to do area correction based on.
    """
    current_area: InputPathType
    """a metric file with vertex areas for the current mesh"""
    new_area: InputPathType
    """a metric file with vertex areas for the new mesh"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-area-metrics")
        cargs.append(execution.input_file(self.current_area))
        cargs.append(execution.input_file(self.new_area))
        return cargs


@dataclasses.dataclass
class CiftiResampleDconnMemoryCerebellumSpheres:
    """
    specify spheres for cerebellum surface resampling.
    """
    current_sphere: InputPathType
    """a sphere with the same mesh as the current cerebellum surface"""
    new_sphere: InputPathType
    """a sphere with the new cerebellum mesh that is in register with the
    current sphere"""
    cerebellum_area_surfs: CiftiResampleDconnMemoryCerebellumAreaSurfs | None = None
    """specify cerebellum surfaces to do vertex area correction based on"""
    cerebellum_area_metrics: CiftiResampleDconnMemoryCerebellumAreaMetrics | None = None
    """specify cerebellum vertex area metrics to do area correction based on"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-spheres")
        cargs.append(execution.input_file(self.current_sphere))
        cargs.append(execution.input_file(self.new_sphere))
        if self.cerebellum_area_surfs is not None:
            cargs.extend(self.cerebellum_area_surfs.run(execution))
        if self.cerebellum_area_metrics is not None:
            cargs.extend(self.cerebellum_area_metrics.run(execution))
        return cargs


class CiftiResampleDconnMemoryOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_resample_dconn_memory(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_resample_dconn_memory(
    cifti_in: InputPathType,
    cifti_template: InputPathType,
    template_direction: str,
    surface_method: str,
    volume_method: str,
    cifti_out: str,
    opt_surface_largest: bool = False,
    volume_predilate: CiftiResampleDconnMemoryVolumePredilate | None = None,
    surface_postdilate: CiftiResampleDconnMemorySurfacePostdilate | None = None,
    affine: CiftiResampleDconnMemoryAffine | None = None,
    warpfield: CiftiResampleDconnMemoryWarpfield | None = None,
    left_spheres: CiftiResampleDconnMemoryLeftSpheres | None = None,
    right_spheres: CiftiResampleDconnMemoryRightSpheres | None = None,
    cerebellum_spheres: CiftiResampleDconnMemoryCerebellumSpheres | None = None,
    runner: Runner | None = None,
) -> CiftiResampleDconnMemoryOutputs:
    """
    Use lots of memory to resample dconn.
    
    This command does the same thing as running -cifti-resample twice, but uses
    memory up to approximately 2x the size that the intermediate file would be.
    This is because the intermediate dconn is kept in memory, rather than
    written to disk, and the components before and after resampling/dilation
    have to be in memory at the same time during the relevant computation. The
    <template-direction> argument should usually be COLUMN, as dtseries,
    dscalar, and dlabel all have brainordinates on that direction. If spheres
    are not specified for a surface structure which exists in the cifti files,
    its data is copied without resampling or dilation. Dilation is done with the
    'nearest' method, and is done on <new-sphere> for surface data. Volume
    components are padded before dilation so that dilation doesn't run into the
    edge of the component bounding box.
    
    To get the v1.3.2 and earlier behavior of weighted dilation, specify
    exponent of 2 for surface and volume, and -legacy-cutoff for both surface
    and volume.
    
    The <volume-method> argument must be one of the following:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR
    
    The <surface-method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti file to resample.
        cifti_template: a cifti file containing the cifti space to resample to.
        template_direction: the direction of the template to use as the\
            resampling space, ROW or COLUMN.
        surface_method: specify a surface resampling method.
        volume_method: specify a volume interpolation method.
        cifti_out: the output cifti file.
        opt_surface_largest: use largest weight instead of weighted average\
            when doing surface resampling.
        volume_predilate: dilate the volume components before resampling.
        surface_postdilate: dilate the surface components after resampling.
        affine: use an affine transformation on the volume components.
        warpfield: use a warpfield on the volume components.
        left_spheres: specify spheres for left surface resampling.
        right_spheres: specify spheres for right surface resampling.
        cerebellum_spheres: specify spheres for cerebellum surface resampling.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiResampleDconnMemoryOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_RESAMPLE_DCONN_MEMORY_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-resample-dconn-memory")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(execution.input_file(cifti_template))
    cargs.append(template_direction)
    cargs.append(surface_method)
    cargs.append(volume_method)
    cargs.append(cifti_out)
    if opt_surface_largest:
        cargs.append("-surface-largest")
    if volume_predilate is not None:
        cargs.extend(volume_predilate.run(execution))
    if surface_postdilate is not None:
        cargs.extend(surface_postdilate.run(execution))
    if affine is not None:
        cargs.extend(affine.run(execution))
    if warpfield is not None:
        cargs.extend(warpfield.run(execution))
    if left_spheres is not None:
        cargs.extend(left_spheres.run(execution))
    if right_spheres is not None:
        cargs.extend(right_spheres.run(execution))
    if cerebellum_spheres is not None:
        cargs.extend(cerebellum_spheres.run(execution))
    ret = CiftiResampleDconnMemoryOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_RESAMPLE_DCONN_MEMORY_METADATA",
    "CiftiResampleDconnMemoryAffine",
    "CiftiResampleDconnMemoryCerebellumAreaMetrics",
    "CiftiResampleDconnMemoryCerebellumAreaSurfs",
    "CiftiResampleDconnMemoryCerebellumSpheres",
    "CiftiResampleDconnMemoryFlirt",
    "CiftiResampleDconnMemoryLeftAreaMetrics",
    "CiftiResampleDconnMemoryLeftAreaSurfs",
    "CiftiResampleDconnMemoryLeftSpheres",
    "CiftiResampleDconnMemoryOutputs",
    "CiftiResampleDconnMemoryRightAreaMetrics",
    "CiftiResampleDconnMemoryRightAreaSurfs",
    "CiftiResampleDconnMemoryRightSpheres",
    "CiftiResampleDconnMemorySurfacePostdilate",
    "CiftiResampleDconnMemoryVolumePredilate",
    "CiftiResampleDconnMemoryWarpfield",
    "CiftiResampleDconnMemoryWeighted",
    "CiftiResampleDconnMemoryWeighted_",
    "cifti_resample_dconn_memory",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CAL_RENORMALIZE_GCA_METADATA = Metadata(
    id="df0026a0e8b6f004896d4b13f1e6b7061efe9b96.boutiques",
    name="mri_cal_renormalize_gca",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCalRenormalizeGcaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_cal_renormalize_gca(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_atlas_file: OutputPathType
    """Renormalized output atlas"""


def mri_cal_renormalize_gca(
    timepoint_file: InputPathType,
    in_vol: InputPathType,
    input_atlas: InputPathType,
    transform_file: InputPathType,
    output_atlas: str,
    runner: Runner | None = None,
) -> MriCalRenormalizeGcaOutputs:
    """
    Tool for atlas renormalization in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        timepoint_file: Longitudinal time point file.
        in_vol: Input volume.
        input_atlas: Input atlas.
        transform_file: Transform file.
        output_atlas: Output atlas.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCalRenormalizeGcaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CAL_RENORMALIZE_GCA_METADATA)
    cargs = []
    cargs.append("mri_cal_renormalize_gca")
    cargs.append(execution.input_file(timepoint_file))
    cargs.append(execution.input_file(in_vol))
    cargs.append(execution.input_file(input_atlas))
    cargs.append(execution.input_file(transform_file))
    cargs.append(output_atlas)
    ret = MriCalRenormalizeGcaOutputs(
        root=execution.output_file("."),
        output_atlas_file=execution.output_file(output_atlas),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CAL_RENORMALIZE_GCA_METADATA",
    "MriCalRenormalizeGcaOutputs",
    "mri_cal_renormalize_gca",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VNO_MATCH_CHECK_METADATA = Metadata(
    id="d1efb9fab3c72ba5b84a4f1cb65492e1bcaadf76.boutiques",
    name="vno_match_check",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class VnoMatchCheckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `vno_match_check(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def vno_match_check(
    subjid: str,
    debug: bool = False,
    right_hemi: bool = False,
    left_hemi: bool = False,
    runner: Runner | None = None,
) -> VnoMatchCheckOutputs:
    """
    Checks that all surfaces and surface data files for a subject have the same
    number of vertices.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: Subject ID for which the vertex number check is performed.
        debug: Prints progress text.
        right_hemi: Checks only the right hemisphere.
        left_hemi: Checks only the left hemisphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VnoMatchCheckOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VNO_MATCH_CHECK_METADATA)
    cargs = []
    cargs.append("vno_match_check")
    cargs.append(subjid)
    if debug:
        cargs.append("debug")
    if right_hemi:
        cargs.append("rh")
    if left_hemi:
        cargs.append("lh")
    ret = VnoMatchCheckOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VNO_MATCH_CHECK_METADATA",
    "VnoMatchCheckOutputs",
    "vno_match_check",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AMP_TO_RSFC_METADATA = Metadata(
    id="27e3a8435ad8a4458d62e5fc746c88a2665d19fa.boutiques",
    name="3dAmpToRSFC",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAmpToRsfcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_amp_to_rsfc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_alff: OutputPathType
    """Amplitude of low frequency fluctuations (L1 sum)."""
    output_malff: OutputPathType
    """ALFF divided by the mean value within the input/estimated whole brain
    mask (mean-scaled ALFF)."""
    output_falff: OutputPathType
    """ALFF divided by sum of full amplitude spectrum (fractional ALFF)."""
    output_rsfa: OutputPathType
    """Square-root of summed square of low frequency fluctuations (L2 sum)."""
    output_mrsfa: OutputPathType
    """RSFA divided by the mean value within the input/estimated whole brain
    mask (mean-scaled RSFA)."""
    output_frsfa: OutputPathType
    """ALFF divided by sum of full amplitude spectrum (fractional RSFA)."""


def v_3d_amp_to_rsfc(
    prefix: str,
    band: list[float],
    in_amp: InputPathType | None = None,
    in_pow: InputPathType | None = None,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dAmpToRsfcOutputs:
    """
    Convert spectral amplitudes into standard RSFC parameters.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output file prefix; file names will be: PREFIX_ALFF,\
            PREFIX_FALFF, etc.
        band: Lower and upper boundaries of the low frequency fluctuations\
            (LFFs), within the interval [FBOT, FTOP].
        in_amp: Input file of one-sided spectral amplitudes, such as output by\
            3dLombScargle.
        in_pow: Input file of a one-sided power spectrum, such as output by\
            3dLombScargle.
        mask: Volume mask of voxels to include for calculations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAmpToRsfcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AMP_TO_RSFC_METADATA)
    cargs = []
    cargs.append("3dAmpToRSFC")
    cargs.append("{")
    if in_amp is not None:
        cargs.extend([
            "-in_amp",
            execution.input_file(in_amp)
        ])
    cargs.append("|")
    if in_pow is not None:
        cargs.extend([
            "-in_pow",
            execution.input_file(in_pow)
        ])
    cargs.append("}")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-band",
        *map(str, band)
    ])
    cargs.append("{")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append("}")
    cargs.append("{")
    cargs.append("-nifti")
    cargs.append("}")
    ret = V3dAmpToRsfcOutputs(
        root=execution.output_file("."),
        output_alff=execution.output_file(prefix + "_ALFF*"),
        output_malff=execution.output_file(prefix + "_MALFF*"),
        output_falff=execution.output_file(prefix + "_FALFF*"),
        output_rsfa=execution.output_file(prefix + "_RSFA*"),
        output_mrsfa=execution.output_file(prefix + "_MRSFA*"),
        output_frsfa=execution.output_file(prefix + "_FRSFA*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAmpToRsfcOutputs",
    "V_3D_AMP_TO_RSFC_METADATA",
    "v_3d_amp_to_rsfc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIRT_NEWDEFAULT_20080811_SCH_METADATA = Metadata(
    id="0d9d4a730463f50ed6f5eaf534671e8d5ad1f460.boutiques",
    name="flirt.newdefault.20080811.sch",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FlirtNewdefault20080811SchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flirt_newdefault_20080811_sch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def flirt_newdefault_20080811_sch(
    term_option: str | None = None,
    curses_flag: bool = False,
    scrollback_flag: bool = False,
    runner: Runner | None = None,
) -> FlirtNewdefault20080811SchOutputs:
    """
    FLIRT (FMRIB's Linear Image Registration Tool) new default configuration script.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        term_option: Use this terminal type instead of $TERM.
        curses_flag: Print curses-version.
        scrollback_flag: Do not try to clear scrollback.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlirtNewdefault20080811SchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIRT_NEWDEFAULT_20080811_SCH_METADATA)
    cargs = []
    cargs.append("flirt.newdefault.20080811.sch")
    if term_option is not None:
        cargs.extend([
            "-T",
            term_option
        ])
    if curses_flag:
        cargs.append("-V")
    if scrollback_flag:
        cargs.append("-x")
    ret = FlirtNewdefault20080811SchOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIRT_NEWDEFAULT_20080811_SCH_METADATA",
    "FlirtNewdefault20080811SchOutputs",
    "flirt_newdefault_20080811_sch",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSELECTVOLS_METADATA = Metadata(
    id="dabd98132f6e29e1943e7c9b7d70ac37b409a5b6.boutiques",
    name="fslselectvols",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslselectvolsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslselectvols(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_4d_image: OutputPathType
    """Output 4D image with selected volumes"""


def fslselectvols(
    input_file: InputPathType,
    output_file: str,
    vols_list: str,
    output_mean_flag: bool = False,
    output_variance_flag: bool = False,
    runner: Runner | None = None,
) -> FslselectvolsOutputs:
    """
    Select volumes from a 4D time series and output a subset 4D volume.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_file: Input file name (4D image).
        output_file: Output file name (4D image).
        vols_list: List of volumes to extract (comma-separated list or ascii\
            file).
        output_mean_flag: Output mean instead of concatenation.
        output_variance_flag: Output variance instead of concatenation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslselectvolsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSELECTVOLS_METADATA)
    cargs = []
    cargs.append("fslselectvols")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    cargs.extend([
        "--vols",
        vols_list
    ])
    if output_mean_flag:
        cargs.append("-m")
    if output_variance_flag:
        cargs.append("-v")
    ret = FslselectvolsOutputs(
        root=execution.output_file("."),
        output_4d_image=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSELECTVOLS_METADATA",
    "FslselectvolsOutputs",
    "fslselectvols",
]
